# -*- coding: utf-8 -*-
"""
xss_utils Django application initialization.
"""
from django.apps import AppConfig


class XssUtilsConfig(AppConfig):
    """
    Configuration for the xss_utils Django application.
    """

    name = 'xss_utils'
